@@ -5,7 +5,10 @@
 import subprocess
 from pathlib import Path
 
-path = Path(__file__).parent #  '/home/oscar/vinka/editors/base/'
+vinca_path = Path(__file__).parent.parent.parent
+tags_path = vinca_path / 'tags.txt'
+
+path = Path(__file__).parent
 vimrc_path = path / '.vimrc'
 
 vimrc_modes = {'a': ['-c', 'startinsert'],
@@ -36,6 +39,8 @@ def edit(card, mode):
 	            f'{card.path}/back',f'{card.path}/tags']
 	# using a vimrc file to make a few custom bindings...
 	vim_cmd += ['-Nu', vimrc_path]
+	# including tag autocompletion
+	vim_cmd += ['-c', f'set dictionary={tags_path}']
 	# with special options depending on the editing mode.
 	vim_cmd += vimrc_modes[mode]
 	# launch
